@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 # daemon/daemon.py
+# Part of python-daemon, an implementation of PEP 3143.
 #
 # Copyright © 2008–2009 Ben Finney <ben+python@benfinney.id.au>
 # Copyright © 2007–2008 Robert Niederreiter, Jens Klein
@@ -29,9 +30,11 @@ import atexit
 class DaemonError(Exception):
     """ Base exception class for errors from this module. """
 
+
 class DaemonOSEnvironmentError(DaemonError, OSError):
     """ Exception raised when daemon OS environment setup receives error. """
 
+
 class DaemonProcessDetachError(DaemonError, OSError):
     """ Exception raised when process detach fails. """
 
@@ -132,16 +135,15 @@ class DaemonContext(object):
               ``DaemonContext`` instance. The attribute's value will be used
               as the action for the signal handler.
 
-            * Any other value will be used as the action for the signal
-              handler.
+            * Any other value will be used as the action for the
+              signal handler. See the ``signal.signal`` documentation
+              for details of the signal handler interface.
 
             The default value depends on which signals are defined on the
             running system. Each item from the list below whose signal is
             actually defined in the ``signal`` module will appear in the
             default map:
 
-            * ``signal.SIGCLD``: ``None``
-
             * ``signal.SIGTTIN``: ``None``
 
             * ``signal.SIGTTOU``: ``None``
@@ -150,6 +152,13 @@ class DaemonContext(object):
 
             * ``signal.SIGTERM``: ``'terminate'``
 
+            Depending on how the program will interact with its child
+            processes, it may need to specify a signal map that
+            includes the ``signal.SIGCHLD`` signal (received when a
+            child process exits). See the specific operating system's
+            documentation for more detail on how to determine what
+            circumstances dictate the need for signal handlers.
+
         `uid`
             :Default: ``os.getuid()``
 
@@ -543,29 +552,28 @@ def detach_process_context():
         Addison-Wesley.
     
         """
-    try:
-        pid = os.fork()
-        if pid > 0:
-            os._exit(0)
-    except OSError, exc:
-        exc_errno = exc.errno
-        exc_strerror = exc.strerror
-        error = DaemonProcessDetachError(
-            "Failed first fork: [%(exc_errno)d] %(exc_strerror)s" % vars())
-        raise error
 
+    def fork_then_exit_parent(error_message):
+        """ Fork a child process, then exit the parent process.
+
+            If the fork fails, raise a ``DaemonProcessDetachError``
+            with ``error_message``.
+
+            """
+        try:
+            pid = os.fork()
+            if pid > 0:
+                os._exit(0)
+        except OSError, exc:
+            exc_errno = exc.errno
+            exc_strerror = exc.strerror
+            error = DaemonProcessDetachError(
+                "%(error_message)s: [%(exc_errno)d] %(exc_strerror)s" % vars())
+            raise error
+
+    fork_then_exit_parent(error_message="Failed first fork")
     os.setsid()
-
-    try:
-        pid = os.fork()
-        if pid > 0:
-            os._exit(0)
-    except OSError, exc:
-        exc_errno = exc.errno
-        exc_strerror = exc.strerror
-        error = DaemonProcessDetachError(
-            "Failed second fork: [%(exc_errno)d] %(exc_strerror)s" % vars())
-        raise error
+    fork_then_exit_parent(error_message="Failed second fork")
 
 
 def is_process_started_by_init():
@@ -727,7 +735,6 @@ def make_default_signal_map():
 
         """
     name_map = {
-        'SIGCLD': None,
         'SIGTSTP': None,
         'SIGTTIN': None,
         'SIGTTOU': None,
