@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # test/test_daemon.py
+# Part of python-daemon, an implementation of PEP 3143.
 #
 # Copyright © 2008–2009 Ben Finney <ben+python@benfinney.id.au>
 #
@@ -14,7 +15,6 @@
 
 import os
 import sys
-from StringIO import StringIO
 import tempfile
 import resource
 import errno
@@ -1797,16 +1797,17 @@ class make_default_signal_map_TestCase(scaffold.TestCase):
         """ Set up test fixtures. """
         self.mock_tracker = scaffold.MockTracker()
 
-        default_signal_map_by_name = {
-            'SIGCLD': None,
-            'SIGTSTP': None,
-            'SIGTTIN': None,
-            'SIGTTOU': None,
-            'SIGTERM': 'terminate',
-            }
-
         mock_signal_module = ModuleType('signal')
-        for name in default_signal_map_by_name:
+        mock_signal_names = [
+            'SIGHUP',
+            'SIGCLD',
+            'SIGSEGV',
+            'SIGTSTP',
+            'SIGTTIN',
+            'SIGTTOU',
+            'SIGTERM',
+            ]
+        for name in mock_signal_names:
             setattr(mock_signal_module, name, object())
 
         scaffold.mock(
@@ -1818,6 +1819,13 @@ class make_default_signal_map_TestCase(scaffold.TestCase):
             mock_obj=mock_signal_module,
             tracker=self.mock_tracker)
 
+        default_signal_map_by_name = {
+            'SIGTSTP': None,
+            'SIGTTIN': None,
+            'SIGTTOU': None,
+            'SIGTERM': 'terminate',
+            }
+
         self.default_signal_map = dict(
             (getattr(signal, name), target)
             for (name, target) in default_signal_map_by_name.items())
@@ -1841,8 +1849,8 @@ class make_default_signal_map_TestCase(scaffold.TestCase):
             defined in the `signal` module.
 
             """
-        del(self.default_signal_map[signal.SIGCLD])
-        del(signal.SIGCLD)
+        del(self.default_signal_map[signal.SIGTTOU])
+        del(signal.SIGTTOU)
         expect_result = self.default_signal_map
         result = daemon.daemon.make_default_signal_map()
         self.failUnlessEqual(expect_result, result)
