@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # test/test_pidlockfile.py
+# Part of python-daemon, an implementation of PEP 3143.
 #
 # Copyright © 2008–2009 Ben Finney <ben+python@benfinney.id.au>
 #
@@ -14,7 +15,6 @@
 
 import __builtin__
 import os
-import sys
 from StringIO import StringIO
 import itertools
 import tempfile
