@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # test/test_runner.py
+# Part of python-daemon, an implementation of PEP 3143.
 #
 # Copyright © 2009 Ben Finney <ben+python@benfinney.id.au>
 #
@@ -15,9 +16,7 @@
 import __builtin__
 import os
 import sys
-import itertools
 import tempfile
-import resource
 import errno
 import signal
 
